# maznet
A lightweight deep learning library made for learning
purposes using Python. The code is easy to understand
but suggestions are welcome and feel free to contact for
queries. We extensively use type hints for better code
comprehension instead of filling our code with docstrings
and comments.

## Requirements
 - numpy

## Setup
You can either download the package from 
`pip install maznet==1.0.0`
or download this repository and use accordingly.

## Usage
See `xor.py` and `fizzbuzz.py` for usage examples

## Future work
Broaden the library functionality by adding more optimizers,
losses, layers and such.

## Contribution
To get assigned to any issue leave a comment or if
you feel you have any ideas feel free to create an issue.
Before making a pull request make sure to check code using
`mypy` for type hints and `black` for linting.

## Acknowledgments
Initial work has been inspired by joelnet.
